@@ -5,7 +5,7 @@ var image = new node_itk.NodeImage('rgb',2);
 console.log('pixel:'+image.GetPixelType());
 console.log(image.GetDimension());
 
-image.Read('rgb',2,'Desert.jpg');
+image.Read('rgb',2,'./Data/Desert.jpg');
 image.Write('rgb.jpg');
 image.Cast('uchar');
 image.Write('uchar.tiff');
